@@ -63,7 +63,7 @@ RemoteImage AbstractKRunnerPlugin::serializeImage(const QImage &image)
     RemoteImage remoteImage{
         convertedImage.width(),
         convertedImage.height(),
-        convertedImage.bytesPerLine(),
+        static_cast<int>(convertedImage.bytesPerLine()),
         true, // hasAlpha
         8, // bitsPerSample
         4, // channels
@@ -71,3 +71,5 @@ RemoteImage AbstractKRunnerPlugin::serializeImage(const QImage &image)
     };
     return remoteImage;
 }
+
+#include "moc_abstractkrunnerplugin.cpp"
